@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::MCP::Config::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::MCP::Config::VERSION = '4.0.5';
+  $Tapper::MCP::Config::VERSION = '4.1.0';
 }
 
 use strict;
@@ -21,6 +21,7 @@ use Sys::Hostname;
 use YAML::Syck qw /Load Dump LoadFile DumpFile/;
 
 use Tapper::Model 'model';
+use Tapper::Cmd::Cobbler;
 use Tapper::Config;
 use Tapper::MCP::Info;
 use Tapper::Producer;
@@ -274,10 +275,36 @@ sub parse_image_precondition
 }
 
 
+
+sub parse_cobbler_preconditions
+{
+        my ($self, $config, $cobbler) = @_;
+        my $cmd = Tapper::Cmd::Cobbler->new();
+        my $host = $self->testrun->testrun_scheduling->host->name;
+        my $error;
+
+
+        # add host if not already known to Cobbler
+        my @hosts = $cmd->host_list({name => $host});
+        if (not @hosts) {
+                # one possible error is a race condition between list and host_new
+                # this should be rare enough to justify the issue for easier development
+                $error = $cmd->host_new({name => $host});
+                return $error if $error;
+        }
+
+        $error  = $cmd->host_update({name => $host, profile => $cobbler->{profile}, "netboot-enabled" => 1});
+        return $error if $error;
+        $config->{cobbler} = $cobbler->{profile};
+        return $config;
+}
+
+
 sub parse_testprogram
 {
         my ($self, $config, $testprogram, $prc_number) = @_;
         $prc_number //= 0;
+        $prc_number = $testprogram->{prc} if $testprogram->{prc}; # allow overriding PRC number for nesting
 
         if (not $testprogram->{timeout}) {
                 $testprogram->{timeout} = $testprogram->{timeout_testprogram};
@@ -292,6 +319,12 @@ sub parse_testprogram
         $testprogram->{timeout} = ($self->cfg->{times}{default_testprogram_timeout} // 600) unless defined $testprogram->{timeout};
         no warnings 'uninitialized';
         push @{$config->{prcs}->[$prc_number]->{config}->{testprogram_list}}, $testprogram;
+
+        $config->{prcs}->[$prc_number]->{mountfile} = $testprogram->{mountfile}
+          if $testprogram->{mountfile} and not $config->{prcs}->[$prc_number]->{mountfile};
+        $config->{prcs}->[$prc_number]->{mountpartition} = $testprogram->{mountpartition}
+          if $testprogram->{mountpartition} and not $config->{prcs}->[$prc_number]->{mountpartition};
+
         $self->mcp_info->add_testprogram($prc_number, $testprogram);
         use warnings;
         return $config;
@@ -373,7 +406,7 @@ sub parse_produce_precondition
         return $produced_preconditions
           unless ref($produced_preconditions) eq 'ARRAY';
         my $position = model->resultset('TestrunPrecondition')->search({testrun_id => $self->testrun->id,
-                                                                        precondition_id => $precondition->id})->first->succession;
+                                                                        precondition_id => $precondition->id}, {rows => 1})->first->succession;
         $self->testrun->disassign_preconditions($precondition->id);
 
         foreach my $produced_precondition (@$produced_preconditions) {
@@ -469,6 +502,9 @@ sub parse_precondition
                 when( 'installer_stop') {
                         $config->{installer_stop} = 1;
                 }
+                when( 'testrun_stop') {
+                        $config->{testrun_stop} = 1;
+                }
                 when( 'reboot') {
                         $config = $self->parse_reboot($config, $precondition);
                 }
@@ -487,6 +523,9 @@ sub parse_precondition
                 when( 'hint' ) {
                         $config=$self->parse_hint_preconditions($config, $precondition);
                 }
+                when( 'cobbler' ) {
+                        $config=$self->parse_cobbler_preconditions($config, $precondition);
+                }
                 default {
                         push @{$config->{preconditions}}, $precondition;
                 }
@@ -563,8 +602,10 @@ sub get_install_config
         # generate installer config
         $config = $self->update_installer_grub($config);
 
+        my $current_prc_number = 0;
         while (my $prc_precondition = shift(@{$config->{prcs}})){
                 $prc_precondition->{precondition_type} = "prc";
+                $prc_precondition->{config}->{guest_number} = $current_prc_number++;
                 push(@{$config->{preconditions}}, $prc_precondition);
         }
 
@@ -610,7 +651,7 @@ sub get_common_config
                 my $path = $config->{paths}{sync_path}."/".$config->{scenario_id}."/";
                 $config->{files}{sync_file} = "$path/syncfile";
 
-                if ($self->testrun->scenario_element->peer_elements->first->testrun->id == $testrun->id) {
+                if ($self->testrun->scenario_element->peer_elements->search({}, {rows => 1})->first->testrun->id == $testrun->id) {
                         if (not -d $path) {
                                 File::Path::mkpath($path, {error => \my $retval});
                         ERROR:
@@ -798,6 +839,16 @@ installed if needed. Care for the root image being installed first.
 @return success - config hash
 @return error   - error string
 
+=head2 parse_cobbler_preconditions
+
+Handle precondition cobbler. Make sure host exists in cobbler system.
+
+@param hash ref - config to change
+@param hash ref - precondition as hash
+
+@return success - config hash
+@return error   - error string
+
 =head2 parse_testprogram
 
 Handle precondition testprogram. Make sure testprogram is correctly to config
